@@ -1,62 +1,65 @@
-import os, shutil, logging
-from subprocess import Popen
+# Copyright 2014 The Emscripten Authors.  All rights reserved.
+# Emscripten is available under two separate licenses, the MIT license and the
+# University of Illinois/NCSA Open Source License.  Both these licenses can be
+# found in the LICENSE file.
+
+import os
+import shutil
 
 TAG = 'version_1'
+HASH = '77f7d8f18fe11bb66a57e358325b7422d721f7b506bd63293cfde74079f958864db66ead5a36c311a76dd8c2b089b7659641a5522de650de0f9e6865782a60dd'
 
-def get_with_configure(ports, settings, shared):
-  if settings.USE_ZLIB == 1:
-    ports.fetch_project('zlib', 'https://github.com/emscripten-ports/zlib/archive/' + TAG + '.zip', 'zlib-' + TAG)
-    return [ports.build_project('zlib', 'zlib-' + TAG,
-                                ['sh', './configure'],
-                                ['libz.a'])]
-  else:
-    return []
 
 def get(ports, settings, shared):
-  if settings.USE_ZLIB == 1:
-    ports.fetch_project('zlib', 'https://github.com/emscripten-ports/zlib/archive/' + TAG + '.zip', 'zlib-' + TAG)
-    def create():     
-      ports.clear_project_build('zlib')
-
-      source_path = os.path.join(ports.get_dir(), 'zlib', 'zlib-' + TAG)
-      dest_path = os.path.join(shared.Cache.get_path('ports-builds'), 'zlib')
-      shared.try_delete(dest_path)
-      os.makedirs(dest_path)
-      shutil.rmtree(dest_path, ignore_errors=True)
-      shutil.copytree(source_path, dest_path)
-      open(os.path.join(dest_path, 'zconf.h'), 'w').write(zconf_h)
-
-      # build
-      srcs = 'adler32.c compress.c crc32.c deflate.c gzclose.c gzlib.c gzread.c gzwrite.c infback.c inffast.c inflate.c inftrees.c trees.c uncompr.c zutil.c'.split(' ')
-      commands = []
-      o_s = []
-      for src in srcs:
-        o = os.path.join(ports.get_build_dir(), 'zlib', src + '.o')
-        shared.safe_ensure_dirs(os.path.dirname(o))
-        commands.append([shared.PYTHON, shared.EMCC, os.path.join(dest_path, src), '-O2', '-o', o, '-I' + dest_path,'-w',])
-        o_s.append(o)
-
-      ports.run_commands(commands)
-      final = os.path.join(ports.get_build_dir(), 'zlib', 'libz.a')
-      shared.try_delete(final)
-      Popen([shared.LLVM_AR, 'rc', final] + o_s).communicate()
-      assert os.path.exists(final)
-      return final
-    return [shared.Cache.get('zlib', create, what='port')]
-  else:
+  if settings.USE_ZLIB != 1:
     return []
 
+  ports.fetch_project('zlib', 'https://github.com/emscripten-ports/zlib/archive/' + TAG + '.zip', 'zlib-' + TAG, sha512hash=HASH)
+
+  def create():
+    ports.clear_project_build('zlib')
+
+    source_path = os.path.join(ports.get_dir(), 'zlib', 'zlib-' + TAG)
+    dest_path = os.path.join(shared.Cache.get_path('ports-builds'), 'zlib')
+    shared.try_delete(dest_path)
+    os.makedirs(dest_path)
+    shutil.rmtree(dest_path, ignore_errors=True)
+    shutil.copytree(source_path, dest_path)
+    open(os.path.join(dest_path, 'zconf.h'), 'w').write(zconf_h)
+
+    # build
+    srcs = 'adler32.c compress.c crc32.c deflate.c gzclose.c gzlib.c gzread.c gzwrite.c infback.c inffast.c inflate.c inftrees.c trees.c uncompr.c zutil.c'.split()
+    commands = []
+    o_s = []
+    for src in srcs:
+      o = os.path.join(ports.get_build_dir(), 'zlib', src + '.o')
+      shared.safe_ensure_dirs(os.path.dirname(o))
+      commands.append([shared.PYTHON, shared.EMCC, os.path.join(dest_path, src), '-O2', '-o', o, '-I' + dest_path, '-w'])
+      o_s.append(o)
+    ports.run_commands(commands)
+
+    final = os.path.join(ports.get_build_dir(), 'zlib', 'libz.a')
+    ports.create_lib(final, o_s)
+    return final
+
+  return [shared.Cache.get('libz.a', create, what='port')]
+
+
+def clear(ports, shared):
+  shared.Cache.erase_file('libz.a')
+
+
 def process_args(ports, args, settings, shared):
   if settings.USE_ZLIB == 1:
     get(ports, settings, shared)
     args += ['-Xclang', '-isystem' + os.path.join(shared.Cache.get_path('ports-builds'), 'zlib')]
   return args
 
+
 def show():
   return 'zlib (USE_ZLIB=1; zlib license)'
 
 
-
 zconf_h = r'''/* zconf.h -- configuration of the zlib compression library
  * Copyright (C) 1995-2013 Jean-loup Gailly.
  * For conditions of distribution and use, see copyright notice in zlib.h
